@@ -49,9 +49,10 @@
 #define CODE_INDENT 4
 #define UNORDERED_LIST_MAX_LEVEL 3
 
-deck_t *markdown_load(FILE *input);
+deck_t *markdown_load(FILE *input, int noexpand);
 int markdown_analyse(cstring_t *text, int prev);
 void markdown_debug(deck_t *deck, int debug);
+void expand_character_entities(line_t *line);
 void adjust_line_length(line_t *line);
 int next_nonblank(cstring_t *text, int i);
 int prev_blank(cstring_t *text, int i);
